@@ -7,8 +7,8 @@
 
 ;; URL: https://codeberg.org/ideasman42/emacs-doc-show-inline
 ;; Keywords: convenience
-;; Package-Version: 20250913.2251
-;; Package-Revision: 4c43aac0867a
+;; Package-Version: 20251030.2355
+;; Package-Revision: bd132bceb567
 ;; Package-Requires: ((emacs "29.1"))
 
 ;;; Commentary:
@@ -95,7 +95,8 @@ does not have a user defined background color."
 (defface doc-show-inline-face (list (list t :extend t))
   "Background for overlays.
 Note that the `background' is initialized using
-`doc-show-inline-face-background-highlight' unless it's customized.")
+`doc-show-inline-face-background-highlight' unless it's customized."
+  :group 'doc-show-inline)
 
 ;; TODO, document and make public.
 (defvar doc-show-inline-mode-defaults
